import { CachedContent, GraphQLConfig } from 'graphql-language-service';
import type { CompletionParams, DidChangeConfigurationParams, DidOpenTextDocumentParams, DidSaveTextDocumentParams } from 'vscode-languageserver/node';
import type { CancellationToken, CompletionItem, CompletionList, Connection, DidChangeConfigurationRegistrationOptions, DidChangeTextDocumentParams, DidChangeWatchedFilesParams, DidCloseTextDocumentParams, DocumentSymbolParams, Hover, InitializeParams, InitializeResult, Location, PublishDiagnosticsParams, SymbolInformation, TextDocumentPositionParams, WorkspaceSymbolParams } from 'vscode-languageserver/node';
import { parseDocument } from './parseDocument';
import { Logger } from './Logger';
import type { LoadConfigOptions } from './types';
import { WorkspaceMessageProcessor } from './WorkspaceMessageProcessor';
export declare class MessageProcessor {
    _connection: Connection;
    _graphQLConfig: GraphQLConfig | undefined;
    _willShutdown: boolean;
    _logger: Logger;
    _parser: (text: string, uri: string) => CachedContent[];
    _tmpDir: string;
    _loadConfigOptions: LoadConfigOptions;
    _rootPath: string;
    _sortedWorkspaceUris: string[];
    _processors: Map<string, WorkspaceMessageProcessor>;
    constructor({ logger, fileExtensions, graphqlFileExtensions, loadConfigOptions, config, parser, tmpDir, connection, }: {
        logger: Logger;
        fileExtensions: string[];
        graphqlFileExtensions: string[];
        loadConfigOptions: LoadConfigOptions;
        config?: GraphQLConfig;
        parser?: typeof parseDocument;
        tmpDir?: string;
        connection: Connection;
    });
    get connection(): Connection;
    set connection(connection: Connection);
    handleInitializeRequest(params: InitializeParams, _token?: CancellationToken, configDir?: string): Promise<InitializeResult>;
    _findWorkspaceProcessor(uri: string): WorkspaceMessageProcessor | undefined;
    handleDidOpenOrSaveNotification(params: DidSaveTextDocumentParams | DidOpenTextDocumentParams): Promise<PublishDiagnosticsParams | null>;
    handleDidChangeNotification(params: DidChangeTextDocumentParams): Promise<PublishDiagnosticsParams | null>;
    handleDidChangeConfiguration(_params: DidChangeConfigurationParams): Promise<DidChangeConfigurationRegistrationOptions>;
    handleDidCloseNotification(params: DidCloseTextDocumentParams): void;
    handleShutdownRequest(): void;
    handleExitNotification(): void;
    validateDocumentAndPosition(params: CompletionParams): void;
    handleCompletionRequest(params: CompletionParams): Promise<CompletionList | Array<CompletionItem>>;
    handleHoverRequest(params: TextDocumentPositionParams): Promise<Hover>;
    handleWatchedFilesChangedNotification(params: DidChangeWatchedFilesParams): Promise<Array<PublishDiagnosticsParams | undefined> | null>;
    handleDefinitionRequest(params: TextDocumentPositionParams, _token?: CancellationToken): Promise<Array<Location>>;
    handleDocumentSymbolRequest(params: DocumentSymbolParams): Promise<Array<SymbolInformation>>;
    handleWorkspaceSymbolRequest(params: WorkspaceSymbolParams): Promise<Array<SymbolInformation>>;
}
//# sourceMappingURL=MessageProcessor.d.ts.map