"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageProcessor = void 0;
const fs_1 = require("fs");
const mkdirp_1 = __importDefault(require("mkdirp"));
const path = __importStar(require("path"));
const vscode_uri_1 = require("vscode-uri");
const parseDocument_1 = require("./parseDocument");
const os_1 = require("os");
const WorkspaceMessageProcessor_1 = require("./WorkspaceMessageProcessor");
class MessageProcessor {
    constructor({ logger, fileExtensions, graphqlFileExtensions, loadConfigOptions, config, parser, tmpDir, connection, }) {
        this._rootPath = process.cwd();
        this._sortedWorkspaceUris = [];
        this._processors = new Map();
        this._connection = connection;
        this._willShutdown = false;
        this._logger = logger;
        this._graphQLConfig = config;
        this._parser = (text, uri) => {
            const p = parser !== null && parser !== void 0 ? parser : parseDocument_1.parseDocument;
            return p(text, uri, fileExtensions, graphqlFileExtensions, this._logger);
        };
        this._tmpDir = tmpDir || (0, os_1.tmpdir)();
        const tmpDirBase = path.join(this._tmpDir, 'graphql-language-service');
        this._loadConfigOptions = { legacy: true, ...loadConfigOptions };
        if (!(0, fs_1.existsSync)(tmpDirBase)) {
            (0, mkdirp_1.default)(tmpDirBase);
        }
    }
    get connection() {
        return this._connection;
    }
    set connection(connection) {
        this._connection = connection;
    }
    async handleInitializeRequest(params, _token, configDir) {
        var _a, _b;
        if (!params) {
            throw new Error('`params` argument is required to initialize.');
        }
        const serverCapabilities = {
            capabilities: {
                workspaceSymbolProvider: true,
                documentSymbolProvider: true,
                completionProvider: {
                    resolveProvider: true,
                    triggerCharacters: [' ', ':', '$', '(', '@'],
                },
                definitionProvider: true,
                textDocumentSync: 1,
                hoverProvider: true,
                workspace: {
                    workspaceFolders: {
                        supported: true,
                        changeNotifications: true,
                    },
                },
            },
        };
        this._sortedWorkspaceUris = (_b = (_a = params.workspaceFolders) === null || _a === void 0 ? void 0 : _a.map(ws => ws.uri).sort((a, b) => b.length - a.length)) !== null && _b !== void 0 ? _b : [
            vscode_uri_1.URI.file(configDir ? configDir.trim() : params.rootUri || this._rootPath).toString(),
        ];
        this._sortedWorkspaceUris.forEach(uri => {
            this._processors.set(uri, new WorkspaceMessageProcessor_1.WorkspaceMessageProcessor({
                connection: this._connection,
                loadConfigOptions: this._loadConfigOptions,
                logger: this._logger,
                parser: this._parser,
                tmpDir: this._tmpDir,
                config: this._graphQLConfig,
                rootPath: vscode_uri_1.URI.parse(uri).fsPath,
            }));
        });
        if (!serverCapabilities) {
            throw new Error('GraphQL Language Server is not initialized.');
        }
        this._logger.info(JSON.stringify({
            type: 'usage',
            messageType: 'initialize',
        }));
        return serverCapabilities;
    }
    _findWorkspaceProcessor(uri) {
        const workspace = this._sortedWorkspaceUris.find(wsUri => uri.startsWith(wsUri));
        return this._processors.get(workspace !== null && workspace !== void 0 ? workspace : '');
    }
    async handleDidOpenOrSaveNotification(params) {
        var _a, _b;
        if (!params || !params.textDocument) {
            throw new Error('`textDocument` argument is required.');
        }
        const { uri } = params.textDocument;
        return ((_b = (_a = this._findWorkspaceProcessor(uri)) === null || _a === void 0 ? void 0 : _a.handleDidOpenOrSaveNotification(params)) !== null && _b !== void 0 ? _b : { uri, diagnostics: [] });
    }
    async handleDidChangeNotification(params) {
        var _a, _b;
        if (!params ||
            !params.textDocument ||
            !params.contentChanges ||
            !params.textDocument.uri) {
            throw new Error('`textDocument`, `textDocument.uri`, and `contentChanges` arguments are required.');
        }
        return ((_b = (_a = this._findWorkspaceProcessor(params.textDocument.uri)) === null || _a === void 0 ? void 0 : _a.handleDidChangeNotification(params)) !== null && _b !== void 0 ? _b : null);
    }
    async handleDidChangeConfiguration(_params) {
        await Promise.all(Array.from(this._processors.values()).map(processor => processor._updateGraphQLConfig()));
        this._logger.log(JSON.stringify({
            type: 'usage',
            messageType: 'workspace/didChangeConfiguration',
        }));
        return {};
    }
    handleDidCloseNotification(params) {
        var _a;
        if (!params || !params.textDocument) {
            throw new Error('`textDocument` is required.');
        }
        const { uri } = params.textDocument;
        (_a = this._findWorkspaceProcessor(uri)) === null || _a === void 0 ? void 0 : _a.handleDidCloseNotification(params);
    }
    handleShutdownRequest() {
        this._willShutdown = true;
        return;
    }
    handleExitNotification() {
        process.exit(this._willShutdown ? 0 : 1);
    }
    validateDocumentAndPosition(params) {
        if (!params ||
            !params.textDocument ||
            !params.textDocument.uri ||
            !params.position) {
            throw new Error('`textDocument`, `textDocument.uri`, and `position` arguments are required.');
        }
    }
    async handleCompletionRequest(params) {
        var _a, _b;
        this.validateDocumentAndPosition(params);
        return ((_b = (_a = this._findWorkspaceProcessor(params.textDocument.uri)) === null || _a === void 0 ? void 0 : _a.handleCompletionRequest(params)) !== null && _b !== void 0 ? _b : []);
    }
    async handleHoverRequest(params) {
        var _a, _b;
        this.validateDocumentAndPosition(params);
        return ((_b = (_a = this._findWorkspaceProcessor(params.textDocument.uri)) === null || _a === void 0 ? void 0 : _a.handleHoverRequest(params)) !== null && _b !== void 0 ? _b : {
            contents: [],
        });
    }
    async handleWatchedFilesChangedNotification(params) {
        return Promise.all(params.changes.map(async (change) => {
            var _a, _b;
            return ((_b = (_a = this._findWorkspaceProcessor(change.uri)) === null || _a === void 0 ? void 0 : _a.handleWatchedFileChangedNotification(change)) !== null && _b !== void 0 ? _b : undefined);
        }));
    }
    async handleDefinitionRequest(params, _token) {
        var _a, _b;
        if (!params || !params.textDocument || !params.position) {
            throw new Error('`textDocument` and `position` arguments are required.');
        }
        return ((_b = (_a = this._findWorkspaceProcessor(params.textDocument.uri)) === null || _a === void 0 ? void 0 : _a.handleDefinitionRequest(params, _token)) !== null && _b !== void 0 ? _b : []);
    }
    async handleDocumentSymbolRequest(params) {
        var _a, _b;
        if (!params || !params.textDocument) {
            throw new Error('`textDocument` argument is required.');
        }
        return ((_b = (_a = this._findWorkspaceProcessor(params.textDocument.uri)) === null || _a === void 0 ? void 0 : _a.handleDocumentSymbolRequest(params)) !== null && _b !== void 0 ? _b : []);
    }
    async handleWorkspaceSymbolRequest(params) {
        return Promise.all(Array.from(this._processors.values()).flatMap(processor => processor.handleWorkspaceSymbolRequest(params))).then(symbolsList => symbolsList.flat());
    }
}
exports.MessageProcessor = MessageProcessor;
//# sourceMappingURL=MessageProcessor.js.map