import { CachedContent, GraphQLConfig, GraphQLProjectConfig, Uri } from 'graphql-language-service';
import { GraphQLLanguageService } from './GraphQLLanguageService';
import type { CompletionParams, DidOpenTextDocumentParams, DidSaveTextDocumentParams, FileEvent, VersionedTextDocumentIdentifier } from 'vscode-languageserver/node';
import type { CancellationToken, CompletionItem, CompletionList, Connection, DidChangeTextDocumentParams, DidCloseTextDocumentParams, DocumentSymbolParams, Hover, Location, PublishDiagnosticsParams, SymbolInformation, TextDocumentPositionParams, WorkspaceSymbolParams } from 'vscode-languageserver/node';
import type { UnnormalizedTypeDefPointer } from '@graphql-tools/load';
import { GraphQLCache } from './GraphQLCache';
import { GraphQLExtensionDeclaration } from 'graphql-config';
import { Logger } from './Logger';
import type { LoadConfigOptions } from './types';
declare type CachedDocumentType = {
    version: number;
    contents: CachedContent[];
};
export declare class WorkspaceMessageProcessor {
    _connection: Connection;
    _graphQLCache: GraphQLCache;
    _graphQLConfig: GraphQLConfig | undefined;
    _languageService: GraphQLLanguageService;
    _textDocumentCache: Map<string, CachedDocumentType>;
    _isInitialized: boolean;
    _isGraphQLConfigMissing: boolean | null;
    _logger: Logger;
    _extensions?: GraphQLExtensionDeclaration[];
    _parser: (text: string, uri: string) => CachedContent[];
    _tmpDir: string;
    _tmpDirBase: string;
    _loadConfigOptions: LoadConfigOptions;
    _rootPath: string;
    _settings: any;
    constructor({ logger, loadConfigOptions, config, parser, tmpDir, connection, rootPath, }: {
        logger: Logger;
        loadConfigOptions: LoadConfigOptions;
        config?: GraphQLConfig;
        parser: (text: string, uri: string) => CachedContent[];
        tmpDir: string;
        connection: Connection;
        rootPath: string;
    });
    _updateGraphQLConfig(): Promise<void>;
    _handleConfigError({ err }: {
        err: unknown;
        uri?: string;
    }): void;
    _logConfigError(errorMessage: string): void;
    handleDidOpenOrSaveNotification(params: DidSaveTextDocumentParams | DidOpenTextDocumentParams): Promise<PublishDiagnosticsParams | null>;
    handleDidChangeNotification(params: DidChangeTextDocumentParams): Promise<PublishDiagnosticsParams | null>;
    handleDidCloseNotification(params: DidCloseTextDocumentParams): void;
    validateDocumentAndPosition(params: CompletionParams): void;
    handleCompletionRequest(params: CompletionParams): Promise<CompletionList | Array<CompletionItem>>;
    handleHoverRequest(params: TextDocumentPositionParams): Promise<Hover>;
    handleWatchedFileChangedNotification(change: FileEvent): Promise<PublishDiagnosticsParams | undefined>;
    handleDefinitionRequest(params: TextDocumentPositionParams, _token?: CancellationToken): Promise<Array<Location>>;
    handleDocumentSymbolRequest(params: DocumentSymbolParams): Promise<Array<SymbolInformation>>;
    handleWorkspaceSymbolRequest(params: WorkspaceSymbolParams): Promise<Array<SymbolInformation>>;
    _getTextDocuments(): [string, CachedDocumentType][];
    _cacheSchemaText(uri: string, text: string, version: number): Promise<void>;
    _cacheSchemaFile(uri: UnnormalizedTypeDefPointer, project: GraphQLProjectConfig): Promise<void>;
    _getTmpProjectPath(project: GraphQLProjectConfig, prependWithProtocol?: boolean, appendPath?: string): string;
    _cacheSchemaPath(uri: string, project: GraphQLProjectConfig): Promise<void>;
    _cacheObjectSchema(pointer: {
        [key: string]: any;
    }, project: GraphQLProjectConfig): Promise<void>;
    _cacheArraySchema(pointers: UnnormalizedTypeDefPointer[], project: GraphQLProjectConfig): Promise<void>;
    _cacheSchemaFilesForProject(project: GraphQLProjectConfig): Promise<void>;
    _cacheConfigSchema(project: GraphQLProjectConfig): Promise<void>;
    _cacheDocumentFilesforProject(project: GraphQLProjectConfig): Promise<void[] | undefined>;
    _cacheAllProjectFiles(config: GraphQLConfig): Promise<void[] | undefined>;
    _isRelayCompatMode(query: string): boolean;
    _updateFragmentDefinition(uri: Uri, contents: CachedContent[]): Promise<void>;
    _updateObjectTypeDefinition(uri: Uri, contents: CachedContent[]): Promise<void>;
    _getCachedDocument(uri: string): CachedDocumentType | null;
    _invalidateCache(textDocument: VersionedTextDocumentIdentifier, uri: Uri, contents: CachedContent[]): Promise<Map<string, CachedDocumentType> | null>;
}
export {};
//# sourceMappingURL=WorkspaceMessageProcessor.d.ts.map